/*
 * @(#)sb16.h  1.1 1999/07/31 Carlos Hasan (chasan@dcc.uchile.cl)
 *
 * Sound Blaster 16 device driver for Intel BeOS Release 4.
 *
 * Copyright (C) 1998 Carlos Hasan. All Rights Reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#ifndef __SB16_H
#define __SB16_H

#include <Drivers.h>

/* ioctl operations */
enum {
    SOUND_GET_PARAMS = B_DEVICE_OP_CODES_END,
    SOUND_SET_PARAMS,
    SOUND_SET_PLAYBACK_COMPLETION_SEM,
    SOUND_SET_CAPTURE_COMPLETION_SEM,
    SOUND_RESERVED_1,
    SOUND_RESERVED_2,
    SOUND_DEBUG_ON,
    SOUND_DEBUG_OFF,
    SOUND_WRITE_BUFFER,
    SOUND_READ_BUFFER,
    SOUND_LOCK_FOR_DMA
};

/* adc input sources */
enum {
    SOUND_ADC_LINE,
    SOUND_ADC_CD,
    SOUND_ADC_MIC,
    SOUND_ADC_LOOPBACK
};

/* sample rates */
enum {
    SOUND_8000_HZ = 0,
    SOUND_11025_HZ = 3,
    SOUND_16000_HZ = 2,
    SOUND_22050_HZ = 7,
    SOUND_32000_HZ = 6,
    SOUND_44100_HZ =10,
    SOUND_48000_HZ = 11
};

/* sample formats */
enum {
    SOUND_PCM_MONO_8_BIT,
    SOUND_PCM_STEREO_8_BIT,
	
    SOUND_ULAW_MONO_8_BIT,
    SOUND_ULAW_STEREO_8_BIT,
	
    SOUND_PCM_MONO_16_BIT,
    SOUND_PCM_STEREO_16_BIT,

    SOUND_ALAW_MONO_8_BIT,
    SOUND_ALAW_STEREO_8_BIT
};

struct sound_channel {
    uint32 adc_source;			/* adc input source */
    char adc_gain;					/* 0..15 adc gain, in 1.5 dB steps */
    char mic_gain_enable;		/* non-zero enables 20 dB MIC input gain */
    char cd_mix_gain;			/* 0..31 cd to output gain in -1.5dB steps */
    char cd_mix_mute;			/* non-zero mutes cd mix */
    char aux2_mix_gain;		/* unused */
    char aux2_mix_mute;		/* unused */
    char line_mix_gain;			/* 0..31 line to output gain in -1.5dB steps */
    char line_mix_mute;			/* non-zero mutes line mix */
    char dac_attn;					/* 0..61 dac attenuation, in -1.5 dB steps */
    char dac_mute;				/* non-zero mutes dac output */
    char reserved_1;
    char reserved_2;
};
 
typedef struct {
    struct sound_channel left;	/* left channel setup */
    struct sound_channel right;	/* right channel setup */
    uint32 sample_rate;				/* sample rate */
    uint32 playback_format;		/* ignore (always 16bit-linear) */
    uint32 capture_format;		/* ignore (always 16bit-linear) */
    char dither_enable;				/* non-zero enables dither on 16 => 8 bit */
    char mic_attn;						/* 0..64 mic input level */
    char mic_enable;					/* non-zero enables mic input */
    char output_boost;				/* ignore (always on) */
    char highpass_enable;			/* ignore (always on) */
    char mono_gain;					/* 0..64 mono speaker gain */
    char mono_mute;					/* non-zero mutes speaker */
} sound_params;

typedef struct {
    int32 buffer_number;
    int32 subscriber_count;
    bigtime_t time;
    int32 reserved_1;
    int32 reserved_2;
    bigtime_t sample_clock;
} sound_buffer_header;
    
#endif
